@@ -111,7 +111,7 @@ class TestCollectionNoConnect(UnitTest):
 
     def test_getattr(self):
         coll = self.db.test
-        self.assertTrue(isinstance(coll["_does_not_exist"], Collection))
+        self.assertIsInstance(coll["_does_not_exist"], Collection)
 
         with self.assertRaises(AttributeError) as context:
             coll._does_not_exist
@@ -176,7 +176,7 @@ class TestCollection(IntegrationTest):
             yield self.db.test
 
     def test_equality(self):
-        self.assertTrue(isinstance(self.db.test, Collection))
+        self.assertIsInstance(self.db.test, Collection)
         self.assertEqual(self.db.test, self.db["test"])
         self.assertEqual(self.db.test, Collection(self.db, "test"))
         self.assertEqual(self.db.test.mike, self.db["test.mike"])
@@ -212,7 +212,7 @@ class TestCollection(IntegrationTest):
 
     def test_drop_nonexistent_collection(self):
         self.db.drop_collection("test")
-        self.assertFalse("test" in self.db.list_collection_names())
+        self.assertNotIn("test", self.db.list_collection_names())
 
         # No exception
         self.db.drop_collection("test")
@@ -248,7 +248,7 @@ class TestCollection(IntegrationTest):
         db.test.drop_indexes()
         self.assertEqual(len(db.test.index_information()), 1)
         db.test.create_indexes([IndexModel("hello")])
-        self.assertTrue("hello_1" in db.test.index_information())
+        self.assertIn("hello_1", db.test.index_information())
 
         db.test.drop_indexes()
         self.assertEqual(len(db.test.index_information()), 1)
@@ -257,7 +257,7 @@ class TestCollection(IntegrationTest):
         )
         info = db.test.index_information()
         for name in names:
-            self.assertTrue(name in info)
+            self.assertIn(name, info)
 
         db.test.drop()
         db.test.insert_one({"a": 1})
@@ -309,16 +309,16 @@ class TestCollection(IntegrationTest):
         db.test.drop_indexes()
         self.assertEqual(len(db.test.index_information()), 1)
         db.test.create_index("hello")
-        self.assertTrue("hello_1" in db.test.index_information())
+        self.assertIn("hello_1", db.test.index_information())
 
         db.test.drop_indexes()
         self.assertEqual(len(db.test.index_information()), 1)
         db.test.create_index([("hello", DESCENDING), ("world", ASCENDING)])
-        self.assertTrue("hello_-1_world_1" in db.test.index_information())
+        self.assertIn("hello_-1_world_1", db.test.index_information())
 
         db.test.drop_indexes()
         db.test.create_index([("hello", DESCENDING), ("world", ASCENDING)], name=None)
-        self.assertTrue("hello_-1_world_1" in db.test.index_information())
+        self.assertIn("hello_-1_world_1", db.test.index_information())
 
         db.test.drop()
         db.test.insert_one({"a": 1})
@@ -347,7 +347,7 @@ class TestCollection(IntegrationTest):
         with self.assertRaises(OperationFailure):
             db.test.drop_index(name)
         self.assertEqual(len(db.test.index_information()), 2)
-        self.assertTrue("hello_1" in db.test.index_information())
+        self.assertIn("hello_1", db.test.index_information())
 
         db.test.drop_indexes()
         db.test.create_index("hello")
@@ -357,7 +357,7 @@ class TestCollection(IntegrationTest):
         self.assertEqual(name, "goodbye_1")
         db.test.drop_index([("goodbye", ASCENDING)])
         self.assertEqual(len(db.test.index_information()), 2)
-        self.assertTrue("hello_1" in db.test.index_information())
+        self.assertIn("hello_1", db.test.index_information())
 
         with self.write_concern_collection() as coll:
             coll.drop_index("hello_1")
@@ -389,7 +389,7 @@ class TestCollection(IntegrationTest):
 
         indexes = (db.test.list_indexes()).to_list()
         self.assertEqual(len(indexes), 1)
-        self.assertTrue("_id_" in map_indexes(indexes))
+        self.assertIn("_id_", map_indexes(indexes))
 
         db.test.create_index("hello")
         indexes = (db.test.list_indexes()).to_list()
@@ -418,7 +418,7 @@ class TestCollection(IntegrationTest):
         db.test.drop()
         db.test.insert_one({})  # create collection
         self.assertEqual(len(db.test.index_information()), 1)
-        self.assertTrue("_id_" in db.test.index_information())
+        self.assertIn("_id_", db.test.index_information())
 
         db.test.create_index("hello")
         self.assertEqual(len(db.test.index_information()), 2)
@@ -478,7 +478,7 @@ class TestCollection(IntegrationTest):
         db.test.drop_indexes()
         self.assertEqual("t_text", db.test.create_index([("t", TEXT)]))
         index_info = (db.test.index_information())["t_text"]
-        self.assertTrue("weights" in index_info)
+        self.assertIn("weights", index_info)
 
         db.test.insert_many(
             [{"t": "spam eggs and spam"}, {"t": "spam"}, {"t": "egg sausage and bacon"}]
@@ -490,7 +490,7 @@ class TestCollection(IntegrationTest):
         # Sort by 'score' field.
         cursor.sort([("score", {"$meta": "textScore"})])
         results = cursor.to_list()
-        self.assertTrue(results[0]["score"] >= results[1]["score"])
+        self.assertGreaterEqual(results[0]["score"], results[1]["score"])
 
         db.test.drop_indexes()
 
@@ -539,7 +539,7 @@ class TestCollection(IntegrationTest):
         db.test.create_index([("keya", ASCENDING)])
         db.test.create_index([("keyb", ASCENDING)], background=False)
         db.test.create_index([("keyc", ASCENDING)], background=True)
-        self.assertFalse("background" in (db.test.index_information())["keya_1"])
+        self.assertNotIn("background", (db.test.index_information())["keya_1"])
         self.assertFalse((db.test.index_information())["keyb_1"]["background"])
         self.assertTrue((db.test.index_information())["keyc_1"]["background"])
 
@@ -690,7 +690,7 @@ class TestCollection(IntegrationTest):
 
         doc = next(db.test.find({}, {"_id": False}))
         l = list(doc)
-        self.assertFalse("_id" in l)
+        self.assertNotIn("_id", l)
 
     def test_options(self):
         db = self.db
@@ -706,8 +706,8 @@ class TestCollection(IntegrationTest):
 
         document: dict[str, Any] = {"_id": 1000}
         result = db.test.insert_one(document)
-        self.assertTrue(isinstance(result, InsertOneResult))
-        self.assertTrue(isinstance(result.inserted_id, int))
+        self.assertIsInstance(result, InsertOneResult)
+        self.assertIsInstance(result.inserted_id, int)
         self.assertEqual(document["_id"], result.inserted_id)
         self.assertTrue(result.acknowledged)
         self.assertIsNotNone(db.test.find_one({"_id": document["_id"]}))
@@ -715,8 +715,8 @@ class TestCollection(IntegrationTest):
 
         document = {"foo": "bar"}
         result = db.test.insert_one(document)
-        self.assertTrue(isinstance(result, InsertOneResult))
-        self.assertTrue(isinstance(result.inserted_id, ObjectId))
+        self.assertIsInstance(result, InsertOneResult)
+        self.assertIsInstance(result.inserted_id, ObjectId)
         self.assertEqual(document["_id"], result.inserted_id)
         self.assertTrue(result.acknowledged)
         self.assertIsNotNone(db.test.find_one({"_id": document["_id"]}))
@@ -724,8 +724,8 @@ class TestCollection(IntegrationTest):
 
         db = db.client.get_database(db.name, write_concern=WriteConcern(w=0))
         result = db.test.insert_one(document)
-        self.assertTrue(isinstance(result, InsertOneResult))
-        self.assertTrue(isinstance(result.inserted_id, ObjectId))
+        self.assertIsInstance(result, InsertOneResult)
+        self.assertIsInstance(result.inserted_id, ObjectId)
         self.assertEqual(document["_id"], result.inserted_id)
         self.assertFalse(result.acknowledged)
         # The insert failed duplicate key...
@@ -737,7 +737,7 @@ class TestCollection(IntegrationTest):
 
         document = RawBSONDocument(encode({"_id": ObjectId(), "foo": "bar"}))
         result = db.test.insert_one(document)
-        self.assertTrue(isinstance(result, InsertOneResult))
+        self.assertIsInstance(result, InsertOneResult)
         self.assertEqual(result.inserted_id, None)
 
     def test_insert_many(self):
@@ -746,38 +746,38 @@ class TestCollection(IntegrationTest):
 
         docs: list = [{} for _ in range(5)]
         result = db.test.insert_many(docs)
-        self.assertTrue(isinstance(result, InsertManyResult))
-        self.assertTrue(isinstance(result.inserted_ids, list))
+        self.assertIsInstance(result, InsertManyResult)
+        self.assertIsInstance(result.inserted_ids, list)
         self.assertEqual(5, len(result.inserted_ids))
         for doc in docs:
             _id = doc["_id"]
-            self.assertTrue(isinstance(_id, ObjectId))
-            self.assertTrue(_id in result.inserted_ids)
+            self.assertIsInstance(_id, ObjectId)
+            self.assertIn(_id, result.inserted_ids)
             self.assertEqual(1, db.test.count_documents({"_id": _id}))
         self.assertTrue(result.acknowledged)
 
         docs = [{"_id": i} for i in range(5)]
         result = db.test.insert_many(docs)
-        self.assertTrue(isinstance(result, InsertManyResult))
-        self.assertTrue(isinstance(result.inserted_ids, list))
+        self.assertIsInstance(result, InsertManyResult)
+        self.assertIsInstance(result.inserted_ids, list)
         self.assertEqual(5, len(result.inserted_ids))
         for doc in docs:
             _id = doc["_id"]
-            self.assertTrue(isinstance(_id, int))
-            self.assertTrue(_id in result.inserted_ids)
+            self.assertIsInstance(_id, int)
+            self.assertIn(_id, result.inserted_ids)
             self.assertEqual(1, db.test.count_documents({"_id": _id}))
         self.assertTrue(result.acknowledged)
 
         docs = [RawBSONDocument(encode({"_id": i + 5})) for i in range(5)]
         result = db.test.insert_many(docs)
-        self.assertTrue(isinstance(result, InsertManyResult))
-        self.assertTrue(isinstance(result.inserted_ids, list))
+        self.assertIsInstance(result, InsertManyResult)
+        self.assertIsInstance(result.inserted_ids, list)
         self.assertEqual([], result.inserted_ids)
 
         db = db.client.get_database(db.name, write_concern=WriteConcern(w=0))
         docs: list = [{} for _ in range(5)]
         result = db.test.insert_many(docs)
-        self.assertTrue(isinstance(result, InsertManyResult))
+        self.assertIsInstance(result, InsertManyResult)
         self.assertFalse(result.acknowledged)
         self.assertEqual(20, db.test.count_documents({}))
 
@@ -818,20 +818,20 @@ class TestCollection(IntegrationTest):
         self.db.test.insert_one({"z": 1})
 
         result = self.db.test.delete_one({"x": 1})
-        self.assertTrue(isinstance(result, DeleteResult))
+        self.assertIsInstance(result, DeleteResult)
         self.assertEqual(1, result.deleted_count)
         self.assertTrue(result.acknowledged)
         self.assertEqual(2, self.db.test.count_documents({}))
 
         result = self.db.test.delete_one({"y": 1})
-        self.assertTrue(isinstance(result, DeleteResult))
+        self.assertIsInstance(result, DeleteResult)
         self.assertEqual(1, result.deleted_count)
         self.assertTrue(result.acknowledged)
         self.assertEqual(1, self.db.test.count_documents({}))
 
         db = self.db.client.get_database(self.db.name, write_concern=WriteConcern(w=0))
         result = db.test.delete_one({"z": 1})
-        self.assertTrue(isinstance(result, DeleteResult))
+        self.assertIsInstance(result, DeleteResult)
         self.assertRaises(InvalidOperation, lambda: result.deleted_count)
         self.assertFalse(result.acknowledged)
 
@@ -849,14 +849,14 @@ class TestCollection(IntegrationTest):
         self.db.test.insert_one({"y": 1})
 
         result = self.db.test.delete_many({"x": 1})
-        self.assertTrue(isinstance(result, DeleteResult))
+        self.assertIsInstance(result, DeleteResult)
         self.assertEqual(2, result.deleted_count)
         self.assertTrue(result.acknowledged)
         self.assertEqual(0, self.db.test.count_documents({"x": 1}))
 
         db = self.db.client.get_database(self.db.name, write_concern=WriteConcern(w=0))
         result = db.test.delete_many({"y": 1})
-        self.assertTrue(isinstance(result, DeleteResult))
+        self.assertIsInstance(result, DeleteResult)
         self.assertRaises(InvalidOperation, lambda: result.deleted_count)
         self.assertFalse(result.acknowledged)
 
@@ -908,10 +908,10 @@ class TestCollection(IntegrationTest):
         with self.assertRaises(OperationFailure):
             db.test.insert_one({"_id": 1, "x": 100})
         result = db.test.insert_one({"_id": 1, "x": 100}, bypass_document_validation=True)
-        self.assertTrue(isinstance(result, InsertOneResult))
+        self.assertIsInstance(result, InsertOneResult)
         self.assertEqual(1, result.inserted_id)
         result = db.test.insert_one({"_id": 2, "a": 0})
-        self.assertTrue(isinstance(result, InsertOneResult))
+        self.assertIsInstance(result, InsertOneResult)
         self.assertEqual(2, result.inserted_id)
 
         db_w0.test.insert_one({"y": 1}, bypass_document_validation=True)
@@ -926,22 +926,22 @@ class TestCollection(IntegrationTest):
         with self.assertRaises(OperationFailure):
             db.test.insert_many(docs)
         result = db.test.insert_many(docs, bypass_document_validation=True)
-        self.assertTrue(isinstance(result, InsertManyResult))
+        self.assertIsInstance(result, InsertManyResult)
         self.assertTrue(97, len(result.inserted_ids))
         for doc in docs:
             _id = doc["_id"]
-            self.assertTrue(isinstance(_id, int))
-            self.assertTrue(_id in result.inserted_ids)
+            self.assertIsInstance(_id, int)
+            self.assertIn(_id, result.inserted_ids)
             self.assertEqual(1, db.test.count_documents({"x": doc["x"]}))
         self.assertTrue(result.acknowledged)
         docs = [{"_id": i, "a": 200 - i} for i in range(100, 200)]
         result = db.test.insert_many(docs)
-        self.assertTrue(isinstance(result, InsertManyResult))
+        self.assertIsInstance(result, InsertManyResult)
         self.assertTrue(97, len(result.inserted_ids))
         for doc in docs:
             _id = doc["_id"]
-            self.assertTrue(isinstance(_id, int))
-            self.assertTrue(_id in result.inserted_ids)
+            self.assertIsInstance(_id, int)
+            self.assertIn(_id, result.inserted_ids)
             self.assertEqual(1, db.test.count_documents({"a": doc["a"]}))
         self.assertTrue(result.acknowledged)
 
@@ -1117,23 +1117,23 @@ class TestCollection(IntegrationTest):
         db.test.insert_one({"x": 1, "mike": "awesome", "extra thing": "abcdefghijklmnopqrstuvwxyz"})
         self.assertEqual(1, db.test.count_documents({}))
         doc = next(db.test.find({}))
-        self.assertTrue("x" in doc)
+        self.assertIn("x", doc)
         doc = next(db.test.find({}))
-        self.assertTrue("mike" in doc)
+        self.assertIn("mike", doc)
         doc = next(db.test.find({}))
-        self.assertTrue("extra thing" in doc)
+        self.assertIn("extra thing", doc)
         doc = next(db.test.find({}, ["x", "mike"]))
-        self.assertTrue("x" in doc)
+        self.assertIn("x", doc)
         doc = next(db.test.find({}, ["x", "mike"]))
-        self.assertTrue("mike" in doc)
+        self.assertIn("mike", doc)
         doc = next(db.test.find({}, ["x", "mike"]))
-        self.assertFalse("extra thing" in doc)
+        self.assertNotIn("extra thing", doc)
         doc = next(db.test.find({}, ["mike"]))
-        self.assertFalse("x" in doc)
+        self.assertNotIn("x", doc)
         doc = next(db.test.find({}, ["mike"]))
-        self.assertTrue("mike" in doc)
+        self.assertIn("mike", doc)
         doc = next(db.test.find({}, ["mike"]))
-        self.assertFalse("extra thing" in doc)
+        self.assertNotIn("extra thing", doc)
 
     @no_type_check
     def test_fields_specifier_as_dict(self):
@@ -1144,8 +1144,8 @@ class TestCollection(IntegrationTest):
 
         self.assertEqual([1, 2, 3], (db.test.find_one())["x"])
         self.assertEqual([2, 3], (db.test.find_one(projection={"x": {"$slice": -2}}))["x"])
-        self.assertTrue("x" not in db.test.find_one(projection={"x": 0}))
-        self.assertTrue("mike" in db.test.find_one(projection={"x": 0}))
+        self.assertNotIn("x", db.test.find_one(projection={"x": 0}))
+        self.assertIn("mike", db.test.find_one(projection={"x": 0}))
 
     def test_find_w_regex(self):
         db = self.db
@@ -1168,7 +1168,7 @@ class TestCollection(IntegrationTest):
         db.test.delete_many({})
         auto_id = {"hello": "world"}
         db.test.insert_one(auto_id)
-        self.assertTrue(isinstance(auto_id["_id"], ObjectId))
+        self.assertIsInstance(auto_id["_id"], ObjectId)
 
         numeric = {"_id": 240, "hello": "world"}
         db.test.insert_one(numeric)
@@ -1180,7 +1180,7 @@ class TestCollection(IntegrationTest):
 
         for x in db.test.find():
             self.assertEqual(x["hello"], "world")
-            self.assertTrue("_id" in x)
+            self.assertIn("_id", x)
 
     def test_unique_index(self):
         db = self.db
@@ -1300,7 +1300,7 @@ class TestCollection(IntegrationTest):
         try:
             self.db.test.update_many({}, {"$thismodifierdoesntexist": 1})
         except OperationFailure as exc:
-            self.assertTrue(exc.code in (9, 10147, 16840, 17009))
+            self.assertIn(exc.code, (9, 10147, 16840, 17009))
             # Just check that we set the error document. Fields
             # vary by MongoDB version.
             self.assertTrue(exc.details is not None)
@@ -1332,9 +1332,9 @@ class TestCollection(IntegrationTest):
 
         id1 = (db.test.insert_one({"x": 1})).inserted_id
         result = db.test.replace_one({"x": 1}, {"y": 1})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(1, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 1))
+        self.assertIn(result.modified_count, (None, 1))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual(1, db.test.count_documents({"y": 1}))
@@ -1343,9 +1343,9 @@ class TestCollection(IntegrationTest):
 
         replacement = RawBSONDocument(encode({"_id": id1, "z": 1}))
         result = db.test.replace_one({"y": 1}, replacement, True)
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(1, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 1))
+        self.assertIn(result.modified_count, (None, 1))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual(1, db.test.count_documents({"z": 1}))
@@ -1353,16 +1353,16 @@ class TestCollection(IntegrationTest):
         self.assertEqual((db.test.find_one(id1))["z"], 1)  # type: ignore
 
         result = db.test.replace_one({"x": 2}, {"y": 2}, True)
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(0, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 0))
-        self.assertTrue(isinstance(result.upserted_id, ObjectId))
+        self.assertIn(result.modified_count, (None, 0))
+        self.assertIsInstance(result.upserted_id, ObjectId)
         self.assertTrue(result.acknowledged)
         self.assertEqual(1, db.test.count_documents({"y": 2}))
 
         db = db.client.get_database(db.name, write_concern=WriteConcern(w=0))
         result = db.test.replace_one({"x": 0}, {"y": 0})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertRaises(InvalidOperation, lambda: result.matched_count)
         self.assertRaises(InvalidOperation, lambda: result.modified_count)
         self.assertRaises(InvalidOperation, lambda: result.upserted_id)
@@ -1377,33 +1377,33 @@ class TestCollection(IntegrationTest):
 
         id1 = (db.test.insert_one({"x": 5})).inserted_id
         result = db.test.update_one({}, {"$inc": {"x": 1}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(1, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 1))
+        self.assertIn(result.modified_count, (None, 1))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual((db.test.find_one(id1))["x"], 6)  # type: ignore
 
         id2 = (db.test.insert_one({"x": 1})).inserted_id
         result = db.test.update_one({"x": 6}, {"$inc": {"x": 1}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(1, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 1))
+        self.assertIn(result.modified_count, (None, 1))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual((db.test.find_one(id1))["x"], 7)  # type: ignore
         self.assertEqual((db.test.find_one(id2))["x"], 1)  # type: ignore
 
         result = db.test.update_one({"x": 2}, {"$set": {"y": 1}}, True)
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(0, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 0))
-        self.assertTrue(isinstance(result.upserted_id, ObjectId))
+        self.assertIn(result.modified_count, (None, 0))
+        self.assertIsInstance(result.upserted_id, ObjectId)
         self.assertTrue(result.acknowledged)
 
         db = db.client.get_database(db.name, write_concern=WriteConcern(w=0))
         result = db.test.update_one({"x": 0}, {"$inc": {"x": 1}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertRaises(InvalidOperation, lambda: result.matched_count)
         self.assertRaises(InvalidOperation, lambda: result.modified_count)
         self.assertRaises(InvalidOperation, lambda: result.upserted_id)
@@ -1434,31 +1434,31 @@ class TestCollection(IntegrationTest):
         db.test.insert_one({"x": 4, "y": 4})
 
         result = db.test.update_many({"x": 4}, {"$set": {"y": 5}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(2, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 2))
+        self.assertIn(result.modified_count, (None, 2))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual(3, db.test.count_documents({"y": 5}))
 
         result = db.test.update_many({"x": 5}, {"$set": {"y": 6}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(1, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 1))
+        self.assertIn(result.modified_count, (None, 1))
         self.assertIsNone(result.upserted_id)
         self.assertTrue(result.acknowledged)
         self.assertEqual(1, db.test.count_documents({"y": 6}))
 
         result = db.test.update_many({"x": 2}, {"$set": {"y": 1}}, True)
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertEqual(0, result.matched_count)
-        self.assertTrue(result.modified_count in (None, 0))
-        self.assertTrue(isinstance(result.upserted_id, ObjectId))
+        self.assertIn(result.modified_count, (None, 0))
+        self.assertIsInstance(result.upserted_id, ObjectId)
         self.assertTrue(result.acknowledged)
 
         db = db.client.get_database(db.name, write_concern=WriteConcern(w=0))
         result = db.test.update_many({"x": 0}, {"$inc": {"x": 1}})
-        self.assertTrue(isinstance(result, UpdateResult))
+        self.assertIsInstance(result, UpdateResult)
         self.assertRaises(InvalidOperation, lambda: result.matched_count)
         self.assertRaises(InvalidOperation, lambda: result.modified_count)
         self.assertRaises(InvalidOperation, lambda: result.upserted_id)
@@ -1538,7 +1538,7 @@ class TestCollection(IntegrationTest):
 
         pipeline = {"$project": {"_id": False, "foo": True}}
         result = db.test.aggregate([pipeline])
-        self.assertTrue(isinstance(result, CommandCursor))
+        self.assertIsInstance(result, CommandCursor)
         self.assertEqual([{"foo": [1, 2]}], result.to_list())
 
         # Test write concern.
@@ -1556,7 +1556,7 @@ class TestCollection(IntegrationTest):
         pipeline = {"$project": {"_id": False, "foo": True}}
         coll = db.get_collection("test", codec_options=CodecOptions(document_class=RawBSONDocument))
         result = coll.aggregate([pipeline])
-        self.assertTrue(isinstance(result, CommandCursor))
+        self.assertIsInstance(result, CommandCursor)
         first_result = next(result)
         self.assertIsInstance(first_result, RawBSONDocument)
         self.assertEqual([1, 2], list(first_result["foo"]))
@@ -1565,7 +1565,7 @@ class TestCollection(IntegrationTest):
         db = self.db
         projection = {"$project": {"_id": "$_id"}}
         cursor = db.test.aggregate([projection], cursor={})
-        self.assertTrue(isinstance(cursor, CommandCursor))
+        self.assertIsInstance(cursor, CommandCursor)
 
     def test_aggregation_cursor(self):
         db = self.db
@@ -1707,21 +1707,21 @@ class TestCollection(IntegrationTest):
         self.assertEqual(db.test.find_one({}), db.test.find_one())
         self.assertEqual(db.test.find_one({"hello": "world"}), db.test.find_one())
 
-        self.assertTrue("hello" in db.test.find_one(projection=["hello"]))
-        self.assertTrue("hello" not in db.test.find_one(projection=["foo"]))
+        self.assertIn("hello", db.test.find_one(projection=["hello"]))
+        self.assertNotIn("hello", db.test.find_one(projection=["foo"]))
 
-        self.assertTrue("hello" in db.test.find_one(projection=("hello",)))
-        self.assertTrue("hello" not in db.test.find_one(projection=("foo",)))
+        self.assertIn("hello", db.test.find_one(projection=("hello",)))
+        self.assertNotIn("hello", db.test.find_one(projection=("foo",)))
 
-        self.assertTrue("hello" in db.test.find_one(projection={"hello"}))
-        self.assertTrue("hello" not in db.test.find_one(projection={"foo"}))
+        self.assertIn("hello", db.test.find_one(projection={"hello"}))
+        self.assertNotIn("hello", db.test.find_one(projection={"foo"}))
 
-        self.assertTrue("hello" in db.test.find_one(projection=frozenset(["hello"])))
-        self.assertTrue("hello" not in db.test.find_one(projection=frozenset(["foo"])))
+        self.assertIn("hello", db.test.find_one(projection=frozenset(["hello"])))
+        self.assertNotIn("hello", db.test.find_one(projection=frozenset(["foo"])))
 
         self.assertEqual(["_id"], list(db.test.find_one(projection={"_id": True})))
-        self.assertTrue("hello" in list(db.test.find_one(projection={})))
-        self.assertTrue("hello" in list(db.test.find_one(projection=[])))
+        self.assertIn("hello", list(db.test.find_one(projection={})))
+        self.assertIn("hello", list(db.test.find_one(projection=[])))
 
         self.assertEqual(None, db.test.find_one({"hello": "foo"}))
         self.assertEqual(None, db.test.find_one(ObjectId()))
@@ -2186,9 +2186,9 @@ class TestCollection(IntegrationTest):
         c.drop()
         c.insert_one({"r": re.compile(".*")})
 
-        self.assertTrue(isinstance((c.find_one())["r"], Regex))  # type: ignore
+        self.assertIsInstance((c.find_one())["r"], Regex)  # type: ignore
         for doc in c.find():
-            self.assertTrue(isinstance(doc["r"], Regex))
+            self.assertIsInstance(doc["r"], Regex)
 
     def test_find_command_generation(self):
         cmd = _gen_find_command(
