@@ -27,8 +27,8 @@ import re
 import sys
 import time
 import traceback
-from asyncio import iscoroutinefunction
 from collections import defaultdict
+from inspect import iscoroutinefunction
 from test import (
     IntegrationTest,
     client_context,
@@ -38,7 +38,6 @@ from test import (
 from test.unified_format_shared import (
     KMS_TLS_OPTS,
     PLACEHOLDER_MAP,
-    SKIP_CSOT_TESTS,
     EventListenerUtil,
     MatchEvaluatorUtil,
     coerce_result,
@@ -48,7 +47,7 @@ from test.unified_format_shared import (
     parse_collection_or_database_options,
     with_metaclass,
 )
-from test.utils import get_pool
+from test.utils import flaky, get_pool
 from test.utils_shared import (
     camel_to_snake,
     camel_to_snake_args,
@@ -66,7 +65,9 @@ from bson import SON, json_util
 from bson.codec_options import DEFAULT_CODEC_OPTIONS
 from bson.objectid import ObjectId
 from gridfs import GridFSBucket, GridOut, NoFile
+from gridfs.errors import CorruptGridFile
 from pymongo import ASCENDING, CursorType, MongoClient, _csot
+from pymongo.driver_info import DriverInfo
 from pymongo.encryption_options import _HAVE_PYMONGOCRYPT
 from pymongo.errors import (
     AutoReconnect,
@@ -130,14 +131,6 @@ def is_run_on_requirement_satisfied(requirement):
     if req_max_server_version:
         max_version_satisfied = Version.from_string(req_max_server_version) >= server_version
 
-    serverless = requirement.get("serverless")
-    if serverless == "require":
-        serverless_satisfied = client_context.serverless
-    elif serverless == "forbid":
-        serverless_satisfied = not client_context.serverless
-    else:  # unset or "allow"
-        serverless_satisfied = True
-
     params_satisfied = True
     params = requirement.get("serverParameters")
     if params:
@@ -167,7 +160,6 @@ def is_run_on_requirement_satisfied(requirement):
         topology_satisfied
         and min_version_satisfied
         and max_version_satisfied
-        and serverless_satisfied
         and params_satisfied
         and auth_satisfied
         and csfle_satisfied
@@ -283,7 +275,7 @@ class EntityMapUtil:
             self._listeners[spec["id"]] = listener
             kwargs["event_listeners"] = [listener]
             if spec.get("useMultipleMongoses"):
-                if client_context.load_balancer or client_context.serverless:
+                if client_context.load_balancer:
                     kwargs["h"] = client_context.MULTI_MONGOS_LB_URI
                 elif client_context.is_mongos:
                     kwargs["h"] = client_context.mongos_seeds()
@@ -439,7 +431,6 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
 
     SCHEMA_VERSION = Version.from_string("1.22")
     RUN_ON_LOAD_BALANCER = True
-    RUN_ON_SERVERLESS = True
     TEST_SPEC: Any
     TEST_PATH = ""  # This gets filled in by generate_test_classes
     mongos_clients: list[MongoClient] = []
@@ -502,19 +493,10 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
             raise unittest.SkipTest(f"{self.__class__.__name__} runOnRequirements not satisfied")
 
         # add any special-casing for skipping tests here
-        if client_context.storage_engine == "mmapv1":
-            if "retryable-writes" in self.TEST_SPEC["description"] or "retryable_writes" in str(
-                self.TEST_PATH
-            ):
-                raise unittest.SkipTest("MMAPv1 does not support retryWrites=True")
 
         # Handle mongos_clients for transactions tests.
         self.mongos_clients = []
-        if (
-            client_context.supports_transactions()
-            and not client_context.load_balancer
-            and not client_context.serverless
-        ):
+        if client_context.supports_transactions() and not client_context.load_balancer:
             for address in client_context.mongoses:
                 self.mongos_clients.append(self.single_client("{}:{}".format(*address)))
 
@@ -532,41 +514,51 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
 
     def maybe_skip_test(self, spec):
         # add any special-casing for skipping tests here
-        if client_context.storage_engine == "mmapv1":
-            if (
-                "Dirty explicit session is discarded" in spec["description"]
-                or "Dirty implicit session is discarded" in spec["description"]
-                or "Cancel server check" in spec["description"]
-            ):
-                self.skipTest("MMAPv1 does not support retryWrites=True")
         if "Client side error in command starting transaction" in spec["description"]:
             self.skipTest("Implement PYTHON-1894")
         if "timeoutMS applied to entire download" in spec["description"]:
             self.skipTest("PyMongo's open_download_stream does not cap the stream's lifetime")
-        if (
-            "Error returned from connection pool clear with interruptInUseConnections=true is retryable"
-            in spec["description"]
-            and not _IS_SYNC
+        if any(
+            x in spec["description"]
+            for x in [
+                "First insertOne is never committed",
+                "Second updateOne is never committed",
+                "Third updateOne is never committed",
+            ]
         ):
-            self.skipTest("PYTHON-5170 tests are flakey")
-        if "Driver extends timeout while streaming" in spec["description"] and not _IS_SYNC:
-            self.skipTest("PYTHON-5174 tests are flakey")
-        if (
-            "inserting _id with type null via clientBulkWrite" in spec["description"]
-            or "commitTransaction fails after Interrupted" in spec["description"]
-            or "commit is not retried after MaxTimeMSExpired error" in spec["description"]
-        ) and client_context.serverless:
-            self.skipTest("PYTHON-5326 known serverless failures")
+            self.skipTest("Implement PYTHON-4597")
 
         class_name = self.__class__.__name__.lower()
         description = spec["description"].lower()
         if "csot" in class_name:
-            if "gridfs" in class_name and sys.platform == "win32":
-                self.skipTest("PYTHON-3522 CSOT GridFS tests are flaky on Windows")
-            if client_context.storage_engine == "mmapv1":
-                self.skipTest(
-                    "MMAPv1 does not support retryable writes which is required for CSOT tests"
-                )
+            # Skip tests that are too slow to run on a given platform.
+            slow_macos = [
+                "operation fails after two consecutive socket timeouts.*",
+                "operation succeeds after one socket timeout.*",
+                "Non-tailable cursor lifetime remaining timeoutMS applied to getMore if timeoutMode is unset",
+            ]
+            slow_win32 = [
+                *slow_macos,
+                "maxTimeMS value in the command is less than timeoutMS",
+                "timeoutMS applies to whole operation.*",
+            ]
+            slow_pypy = [
+                "timeoutMS applies to whole operation.*",
+            ]
+            if "CI" in os.environ and sys.platform == "win32" and "gridfs" in class_name:
+                self.skipTest("PYTHON-3522 CSOT GridFS test runs too slow on Windows")
+            if "CI" in os.environ and sys.platform == "win32":
+                for pat in slow_win32:
+                    if re.match(pat.lower(), description):
+                        self.skipTest("PYTHON-3522 CSOT test runs too slow on Windows")
+            if "CI" in os.environ and sys.platform == "darwin":
+                for pat in slow_macos:
+                    if re.match(pat.lower(), description):
+                        self.skipTest("PYTHON-3522 CSOT test runs too slow on MacOS")
+            if "CI" in os.environ and sys.implementation.name.lower() == "pypy":
+                for pat in slow_pypy:
+                    if re.match(pat.lower(), description):
+                        self.skipTest("PYTHON-3522 CSOT test runs too slow on PyPy")
             if "change" in description or "change" in class_name:
                 self.skipTest("CSOT not implemented for watch()")
             if "cursors" in class_name:
@@ -591,11 +583,6 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
                 self.skipTest("PyMongo does not support count()")
             if name == "listIndexNames":
                 self.skipTest("PyMongo does not support list_index_names()")
-            if client_context.storage_engine == "mmapv1":
-                if name == "createChangeStream":
-                    self.skipTest("MMAPv1 does not support change streams")
-                if name == "withTransaction" or name == "startTransaction":
-                    self.skipTest("MMAPv1 does not support document-level locking")
             if not client_context.test_commands_enabled:
                 if name == "failPoint" or name == "targetedFailPoint":
                     self.skipTest("Test commands must be enabled to use fail points")
@@ -635,6 +622,8 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
             # Connection errors are considered client errors.
             if isinstance(error, ConnectionFailure):
                 self.assertNotIsInstance(error, NotPrimaryError)
+            elif isinstance(error, CorruptGridFile):
+                pass
             elif isinstance(error, (InvalidOperation, ConfigurationError, EncryptionError, NoFile)):
                 pass
             else:
@@ -691,7 +680,7 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
                 self.match_evaluator.match_result(expect_result, result)
             else:
                 self.fail(
-                    f"expectResult can only be specified with {BulkWriteError} or {ClientBulkWriteException} exceptions"
+                    f"expectResult can only be specified with {BulkWriteError} or {ClientBulkWriteException} exceptions, got {exception}"
                 )
 
         return exception
@@ -701,8 +690,6 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
             self.fail(f"Operation {opname} not supported for entity of type {type(target)}")
 
     def __entityOperation_createChangeStream(self, target, *args, **kwargs):
-        if client_context.storage_engine == "mmapv1":
-            self.skipTest("MMAPv1 does not support change streams")
         self.__raise_if_unsupported("createChangeStream", target, MongoClient, Database, Collection)
         stream = target.watch(*args, **kwargs)
         self.addCleanup(stream.close)
@@ -827,14 +814,10 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
         return (target.list_search_indexes(name, **agg_kwargs)).to_list()
 
     def _sessionOperation_withTransaction(self, target, *args, **kwargs):
-        if client_context.storage_engine == "mmapv1":
-            self.skipTest("MMAPv1 does not support document-level locking")
         self.__raise_if_unsupported("withTransaction", target, ClientSession)
         return target.with_transaction(*args, **kwargs)
 
     def _sessionOperation_startTransaction(self, target, *args, **kwargs):
-        if client_context.storage_engine == "mmapv1":
-            self.skipTest("MMAPv1 does not support document-level locking")
         self.__raise_if_unsupported("startTransaction", target, ClientSession)
         return target.start_transaction(*args, **kwargs)
 
@@ -857,6 +840,11 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
         self.__raise_if_unsupported("close", target, NonLazyCursor, CommandCursor)
         return target.close()
 
+    def _clientOperation_appendMetadata(self, target, *args, **kwargs):
+        info_opts = kwargs["driver_info_options"]
+        driver_info = DriverInfo(info_opts["name"], info_opts["version"], info_opts["platform"])
+        target.append_metadata(driver_info)
+
     def _clientEncryptionOperation_createDataKey(self, target, *args, **kwargs):
         if "opts" in kwargs:
             kwargs.update(camel_to_snake_args(kwargs.pop("opts")))
@@ -994,13 +982,9 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
             if ignore and isinstance(exc, (PyMongoError,)):
                 return exc
             if expect_error:
-                if method_name == "_collectionOperation_bulkWrite":
-                    self.skipTest("Skipping test pending PYTHON-4598")
                 return self.process_error(exc, expect_error)
             raise
         else:
-            if method_name == "_collectionOperation_bulkWrite":
-                self.skipTest("Skipping test pending PYTHON-4598")
             if expect_error:
                 self.fail(f'Excepted error {expect_error} but "{opname}" succeeded: {result}')
 
@@ -1381,38 +1365,31 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
                 self.assertListEqual(sorted_expected_documents, actual_documents)
 
     def run_scenario(self, spec, uri=None):
-        if "csot" in self.id().lower() and SKIP_CSOT_TESTS:
-            raise unittest.SkipTest("SKIP_CSOT_TESTS is set, skipping...")
-
         # Kill all sessions before and after each test to prevent an open
         # transaction (from a test failure) from blocking collection/database
         # operations during test set up and tear down.
         self.kill_all_sessions()
 
-        if "csot" in self.id().lower():
-            # Retry CSOT tests up to 2 times to deal with flakey tests.
-            attempts = 3
-            for i in range(attempts):
-                try:
-                    return self._run_scenario(spec, uri)
-                except (AssertionError, OperationFailure) as exc:
-                    if isinstance(exc, OperationFailure) and (
-                        _IS_SYNC or "failpoint" not in exc._message
-                    ):
-                        raise
-                    if i < attempts - 1:
-                        print(
-                            f"Retrying after attempt {i+1} of {self.id()} failed with:\n"
-                            f"{traceback.format_exc()}",
-                            file=sys.stderr,
-                        )
-                        self.setUp()
-                        continue
-                    raise
-            return None
-        else:
-            self._run_scenario(spec, uri)
-            return None
+        # Handle flaky tests.
+        flaky_tests = [
+            ("PYTHON-5170", ".*test_discovery_and_monitoring.*"),
+            ("PYTHON-5174", ".*Driver_extends_timeout_while_streaming"),
+            ("PYTHON-5315", ".*TestSrvPolling.test_recover_from_initially_.*"),
+            ("PYTHON-4987", ".*UnknownTransactionCommitResult_labels_to_connection_errors"),
+            ("PYTHON-3689", ".*TestProse.test_load_balancing"),
+            ("PYTHON-3522", ".*csot.*"),
+        ]
+        for reason, flaky_test in flaky_tests:
+            if re.match(flaky_test.lower(), self.id().lower()) is not None:
+                func_name = self.id()
+                options = dict(reason=reason, reset_func=self.setUp, func_name=func_name)
+                if "csot" in func_name.lower():
+                    options["max_runs"] = 3
+                    options["affects_cpython_linux"] = True
+                decorator = flaky(**options)
+                decorator(self._run_scenario)(spec, uri)
+                return
+        self._run_scenario(spec, uri)
 
     def _run_scenario(self, spec, uri=None):
         # maybe skip test manually
